# -*- encoding: utf-8 -*-
#
# Copyright 2017 Red Hat, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.


RESOURCE = 'files_events'


def list(context, sequence, limit=10, offset=0):
    params = {'limit': limit,
              'offset': offset}
    uri = '%s/%s/%s' % (context.dci_cs_api, RESOURCE, sequence)
    return context.session.get(uri, params=params)


def iter(context, sequence, limit=10):
    """Iter to list all the files events."""
    params = {'limit': limit,
              'offset': 0}
    uri = '%s/%s/%s' % (context.dci_cs_api, RESOURCE, sequence)

    while True:
        j = context.session.get(uri, params=params).json()
        if len(j['files']):
            for i in j['files']:
                yield i
        else:
            break
        params['offset'] += params['limit']



# -*- encoding: utf-8 -*-
#
# Copyright 2017 Red Hat, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

from __future__ import unicode_literals


def test_prettytable_output(runner):
    role = runner.invoke_raw_parse([
        'role-create',
        '--name', 'foo'])
    assert role['name'] == 'foo'
    assert role == runner.invoke_raw_parse([
        'role-show', role['id']])


def test_success_create_basic(runner):
    role = runner.invoke(['role-create', '--name', 'myrole'])['role']
    assert role['name'] == 'myrole'


def test_success_create_full(runner):
    role = runner.invoke(['role-create', '--name', 'myrole', '--label',
                          'MYROLE', '--description', 'myrole', '--state',
                          'active'])['role']
    assert role['name'] == 'myrole'
    assert role['label'] == 'MYROLE'
    assert role['description'] == 'myrole'
    assert role['state'] == 'active'


def test_list(runner):
    roles_number = len(runner.invoke(['role-list'])['roles'])

    runner.invoke(['role-create', '--name', 'foo'])
    runner.invoke(['role-create', '--name', 'bar'])

    roles_new_number = len(runner.invoke(['role-list'])['roles'])

    assert roles_new_number == roles_number + 2


def test_fail_create_unauthorized_user_admin(runner_user_admin):
    role = runner_user_admin.invoke(['role-create', '--name', 'foo'])
    assert role['status_code'] == 401


def test_fail_create_unauthorized_user(runner_user):
    role = runner_user.invoke(['role-create', '--name', 'foo'])
    assert role['status_code'] == 401


def test_success_update(runner):
    role = runner.invoke(['role-create', '--name', 'foo', '--description',
                          'foo_desc'])['role']

    result = runner.invoke(['role-update', role['id'],
                            '--etag', role['etag'], '--name', 'bar',
                            '--description', 'bar_desc'])

    assert result['message'] == 'Role updated.'
    assert result['id'] == role['id']

    role = runner.invoke(['role-show', role['id']])['role']

    assert role['name'] == 'bar'
    assert role['description'] == 'bar_desc'


def test_delete(runner):
    role = runner.invoke(['role-create', '--name', 'foo'])['role']

    result = runner.invoke(['role-delete', role['id'],
                            '--etag', role['etag']])

    assert result['message'] == 'Role deleted.'

    result = runner.invoke(['role-show', role['id']])

    assert result['status_code'] == 404


def test_show(runner):
    role = runner.invoke(['role-create', '--name', 'foo'])['role']

    role = runner.invoke(['role-show', role['id']])['role']

    assert role['name'] == 'foo'



# -*- coding: utf-8 -*-
#
# Copyright (C) 2017 Red Hat, Inc
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

from dciclient.v1.api import file
from dciclient.v1.api import files_events


def test_files_events_create(dci_context, job_id):

    file_json = file.create(dci_context, 'name1', 'content1',
                            mime='text/plain', job_id=job_id).json()
    file_id = file_json['file']['id']
    f_events = files_events.list(dci_context, 0)
    assert f_events.status_code == 200

    f_events_data = f_events.json()
    assert f_events_data['files'][-1]['event']['file_id'] == file_id
    assert f_events_data['files'][-1]['event']['action'] == 'create'


def test_files_events_delete(dci_context, job_id):

    file_json = file.create(dci_context, 'name1', 'content1',
                            mime='text/plain', job_id=job_id).json()
    file_id = file_json['file']['id']
    file.delete(dci_context, file_id)
    f_events = files_events.list(dci_context, 0)
    assert f_events.status_code == 200

    f_events_data = f_events.json()
    assert f_events_data['files'][-1]['event']['file_id'] == file_id
    assert f_events_data['files'][-1]['event']['action'] == 'delete'



# -*- encoding: utf-8 -*-
#
# Copyright 2017 Red Hat, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

import click

from dciclient.v1.shell_commands import cli
from dciclient.v1 import utils

from dciclient.v1.api import role


@cli.command("role-list", help="List all roles.")
@click.pass_obj
def list(context):
    """list(context)

    List all roles.

    >>> dcictl role list

    """
    result = role.list(context)
    utils.format_output(result, context.format)


@cli.command("role-create", help="Create a role.")
@click.option("--name", required=True)
@click.option("--label", required=False)
@click.option("--description", required=False)
@click.option("--state", required=False)
@click.pass_obj
def create(context, name, label, description, state):
    """create(context, name, label, description, state)

    Create a role.

    >>> dcictl role-create [OPTIONS]

    :param string name: Name of the role [required]
    :param string label: Label of the role [optional]
    :param string description: Description of the role [optional]
    :param string state: State of the role [optional]
    """
    result = role.create(context, name=name, label=label,
                         description=description, state=state)
    utils.format_output(result, context.format)


@cli.command("role-update", help="Update a role.")
@click.argument("id")
@click.option("--etag", required=True)
@click.option("--name", required=False)
@click.option("--description", required=False)
@click.option("--state", required=False)
@click.pass_obj
def update(context, id, etag, name, description, state):
    """update(context, id, etag, name, description, state)

    Update a role.

    >>> dcictl role-update [OPTIONS]

    :param string id: ID of the role to update [required]
    :param string etag: Entity tag of the resource [required]
    :param string name: New name of the role [required]
    :param string description: New description of the role [required]
    :param string state: New state of the role [required]
    """
    result = role.update(context, id=id, etag=etag, name=name,
                         description=description, state=state)

    if result.status_code == 204:
        utils.print_json({'id': id, 'message': 'Role updated.'})
    else:
        utils.format_output(result, context.format)


@cli.command("role-delete", help="Delete a role.")
@click.argument("id")
@click.option("--etag", required=True)
@click.pass_obj
def delete(context, id, etag):
    """delete(context, id, etag)

    Delete a role.

    >>> dcictl role-delete [OPTIONS]

    :param string id: ID of the role to delete [required]
    :param string etag: Entity tag of resource [required]
    """
    result = role.delete(context, id=id, etag=etag)

    if result.status_code == 204:
        utils.print_json({'id': id, 'message': 'Role deleted.'})
    else:
        utils.format_output(result, context.format)


@cli.command("role-show", help="Show a role.")
@click.argument("id")
@click.pass_obj
def show(context, id):
    """show(context, id)

    Show a role.

    >>> dcictl role-show [OPTIONS]

    :param string id: ID of the role to return [required]
    """
    result = role.get(context, id=id)
    utils.format_output(result, context.format)
